Welcome to DAX's documentation!
===============================

DAX is Distributed Automation for `XNAT <http://xnat.org/>`_

DAX allows you to:

- store analyzed imaging data on XNAT (datatypes)
- extract information from XNAT via scripts (Xnat_tools)
- run pipelines on your data in XNAT via a cluster (processors)


Installation 
------------

To install please reference our `Install Page <https://dax.readthedocs.io/en/latest/installing_dax_in_a_virtual_environment.html>`_

Contents:

.. toctree::
   :maxdepth: 3
   
   installing_dax_in_a_virtual_environment
   dax_xnat_dataypes_install
   dax
   dax_manager
   contributors
   how_to_contribute
   faq
   processors
   processors_v3
   assessors_in_vuiis_xnat
   dax_command_line_tools
   dax_executables
   manage_a_project
   BIDS_walkthrough 
